@@ -26,13 +26,14 @@ if not os.getenv("READ_THE_DOCS"):
     )
     from cognite.seismic.protos.types_pb2 import (
         CRS,
+        Dimensions,
+        ExternalId,
         FileStep,
         GeoJson,
         Geometry,
         LineBasedRectangle,
         PositionQuery,
         Wkt,
-        ExternalId,
     )
     from google.protobuf.empty_pb2 import Empty
 
@@ -255,7 +256,7 @@ class FileAPI(API):
         survey_name: Optional[str] = None,
         bucket: Optional[str] = None,
         file_name: str = None,
-        crs: str = None,
+        crs: Optional[str] = None,
         metadata: dict = None,
         is_temporary: bool = False,
         inline_offset: Optional[int] = None,
@@ -264,6 +265,7 @@ class FileAPI(API):
         cdp_y_offset: Optional[int] = None,
         source_group_scalar_override: Optional[float] = None,
         external_id: Optional[str] = None,
+        dimensions: int = 3,
     ):
         """Register a file on a survey
 
@@ -272,20 +274,26 @@ class FileAPI(API):
             survey_name (str): The survey is identified by either the id or the name. If both are given, the id is used.
             bucket (str): Path to the directory in Google Cloud Storage in which the file is stored
             file_name (str): The file name in Google Cloud Storage. Also used for identifying the file
-            crs (str): The CRS of the file
+            crs (str, optional): The CRS of the file. If not given, the CRS will be taken from the survey.
             metadata (dict, optional): A string -> string dictionary with any metadata to add about the file
             is_temporary: is the file temporary - ie generated on the fly instead of being ingested from the bucket
             inline_offset: Byte offset of inline number field in the trace headers. Defaults to 189 as per the SEG-Y rev1 specification
             xline_offset: Byte offset of crossline number field in the trace headers. Defaults to 193 as per the SEG-Y rev1 specification
             cdp_x_offset: Byte offset of x coordinate of ensemble (CDP) position in trace headers. Defaults to 181 as per the SEG-Y rev1 specification
             cdp_y_offset: Byte offset of y coordinate of ensemble (CDP) position in trace headers. Defaults to 185 as per the SEG-Y rev1 specification
-            source_group_scalar_override: Multiplier for CDP-X and CDP-Y values, overrides scalar factor obtained from trace header
+            source_group_scalar_override: Multiplier for CDP-X and CDP-Y values, overrides scalar factor obtained from trace header.
+
+                Note that this is a straight multiplier to be applied, not a value to be interpreted like he SEG-Y trace header field.
+                Valid values for this parameter are in the range 0.0 < n <= 1.0
+
             external_id: An optional external id for a file
+            dimensions: The dimensionality of the file data, either 2 or 3. Defaults to 3D if omitted
 
         Returns:
              The response from the gRPC server with the id the file was registered on.
         """
         survey = self.identify(survey_id, survey_name)
+        crs = CRS(crs=crs) if crs is not None else None
         inline_offset_wrapped = None if inline_offset == None else wrappers.Int32Value(value=inline_offset)
         xline_offset_wrapped = None if xline_offset == None else wrappers.Int32Value(value=xline_offset)
         cdp_x_offset_wrapped = None if cdp_x_offset == None else wrappers.Int32Value(value=cdp_x_offset)
@@ -294,11 +302,19 @@ class FileAPI(API):
             None if source_group_scalar_override == None else wrappers.FloatValue(value=source_group_scalar_override)
         )
         external_id = None if external_id == None else ExternalId(external_id=external_id)
+
+        if dimensions == 2:
+            dimensions_enum = Dimensions.Value("TWO_DEE")
+        elif dimensions == 3:
+            dimensions_enum = Dimensions.Value("THREE_DEE")
+        else:
+            raise Exception("Invalid `dimensions`. Must be either 2 or 3")
+
         request = RegisterFileRequest(
             survey=survey,
             path=bucket,
             name=file_name,
-            crs=CRS(crs=crs),
+            crs=crs,
             metadata=metadata,
             is_temporary=wrappers.BoolValue(value=is_temporary),
             inline_offset=inline_offset_wrapped,
@@ -307,6 +323,7 @@ class FileAPI(API):
             cdp_y_offset=cdp_y_offset_wrapped,
             source_group_scalar_override=source_group_scalar_override,
             external_id=external_id,
+            dimensions=dimensions_enum,
         )
         return self.ingestion.RegisterFile(request)
 
@@ -396,6 +413,11 @@ class FileAPI(API):
             cdp_x_offset: Byte offset of x coordinate of ensemble (CDP) position in trace headers.
             cdp_y_offset: Byte offset of y coordinate of ensemble (CDP) position in trace headers.
             source_group_scalar_override: Multiplier for CDP-X and CDP-Y values, overrides scalar factor obtained from trace header.
+
+                Note that this is a straight multiplier to be applied, not a value to be interpreted like he SEG-Y trace header field.
+                Valid values for scalars multipliers are in the range 0.0 < n <= 1.0.
+                To delete an existing source group scalar override set on a file, supply 0.0 or NaN in this argument.
+
             external_id: External id of the file
 
         Returns:
