@@ -522,7 +522,7 @@ class File:
 
     def __repr__(self):
         temporary = ", temporary" if self.is_temporary else ""
-        return f"File<id: {self.id}, name: {self.name}{temporary}, metadata: {self.metadata}, external_id: {self.external_id}>"
+        return f"File<id: {repr(self.id)}, name: {repr(self.name)}{temporary}, metadata: {self.metadata}, external_id: {repr(self.external_id)}>"
 
     @staticmethod
     def from_proto(proto) -> "File":
@@ -546,8 +546,9 @@ class SourceSegyFile:
         id (int): A 64-bit integer that represents the source file internally within the seismic service.
         external_id (str): A string-based user id that uniquely identifies the file.
         name (str): Non-unique string that describes the file.
+        cloud_storage_path (str): The cloud storage path where the file is located.
         metadata (Mapping[str, str]): User-provided metadata in the form of a string to string mapping
-        segy_overrides (SegyOverrides): 
+        segy_overrides (SegyOverrides):
 
     """
 
@@ -555,16 +556,21 @@ class SourceSegyFile:
     id: int
     external_id: str
     name: str
+    cloud_storage_path: str
     metadata: Mapping[str, str]
     segy_overrides: "SegyOverrides"
 
-    def __init__(self, *, uuid, id, external_id, name, metadata, segy_overrides):
+    def __init__(self, *, uuid, id, external_id, name, metadata, segy_overrides, cloud_storage_path):
         self.uuid = uuid
         self.id = id
         self.external_id = external_id
         self.name = name
         self.metadata = metadata
         self.segy_overrides = segy_overrides
+        self.cloud_storage_path = cloud_storage_path
+
+    def __repr__(self):
+        return f"SourceSegyFile<uuid: {repr(self.uuid)}, id: {self.id}, external_id: {repr(self.external_id)}, name: {repr(self.name)}, metadata: {self.metadata}, segy_overrides: {repr(self.segy_overrides)}>"
 
     @staticmethod
     def from_proto(proto) -> "SourceSegyFile":
@@ -574,15 +580,22 @@ class SourceSegyFile:
         name = proto.name
         metadata = proto.metadata
         segy_overrides = SegyOverrides.from_proto(proto.segy_overrides)
+        cloud_storage_path = proto.cloud_storage_path
 
         return SourceSegyFile(
-            uuid=uuid, id=id, external_id=external_id, name=name, metadata=metadata, segy_overrides=segy_overrides
+            uuid=uuid,
+            id=id,
+            external_id=external_id,
+            name=name,
+            metadata=metadata,
+            segy_overrides=segy_overrides,
+            cloud_storage_path=cloud_storage_path,
         )
 
 
 class SegyOverrides:
     """A set of SegY header overrides for a given ingested file.
-    
+
     Attributes:
         inline_offset (Optional[int])
         crossline_offset (Optional[int])
@@ -604,6 +617,9 @@ class SegyOverrides:
         self.cdp_y_offset = cdp_y_offset
         self.source_group_scalar_override = source_group_scalar_override
 
+    def __repr__(self):
+        return f"SegyOverrides<inline_offset: {self.inline_offset}, crossline_offset: {self.crossline_offset}, cdp_x_offset: {self.cdp_x_offset}, cdp_y_offset: {self.cdp_y_offset}, source_group_scalar_override: {self.source_group_scalar_override}>"
+
     @staticmethod
     def from_proto(proto) -> "SegyOverrides":
         """Convert a SegyOverrides proto into a python object"""
@@ -647,9 +663,9 @@ class Geometry:
 
     def __repr__(self):
         if self.geojson:
-            return f"Geometry<crs: {self.crs}, geojson: {self.geojson}>"
+            return f"Geometry<crs: {repr(self.crs)}, geojson: {self.geojson}>"
         else:
-            return f"Geometry<crs: {self.crs}, wkt: {self.wkt}>"
+            return f"Geometry<crs: {repr(self.crs)}, wkt: {repr(self.wkt)}>"
 
     @staticmethod
     def from_proto(proto) -> Union["Geometry", None]:
@@ -693,7 +709,7 @@ class TextHeader:
         self.raw_header = raw_header
 
     def __repr__(self):
-        return f"TextHeader<{self.header}>"
+        return f"TextHeader<{repr(self.header)}>"
 
     def from_proto(proto):
         return TextHeader(header=proto.header, raw_header=proto.raw_header)
@@ -909,7 +925,7 @@ class SeismicStore:
         self.storage_tier_name = storage_tier_name
 
     def __repr__(self):
-        return f"SeismicStore<id: {self.id}, name: {self.name}, survey_id: {self.survey_id}, ingestion_source: {self.ingestion_source}, metadata: {self.metadata}, storage_tier: {self.storage_tier_name}>"
+        return f"SeismicStore<id: {self.id}, name: {repr(self.name)}, survey_id: {repr(self.survey_id)}, ingestion_source: {self.ingestion_source}, metadata: {self.metadata}, storage_tier: {repr(self.storage_tier_name)}>"
 
     @staticmethod
     def from_proto(proto) -> "SeismicStore":
@@ -1057,7 +1073,7 @@ class Seismic:
         self.trace_count = trace_count
 
     def __repr__(self):
-        return f"Seismic<id: {self.id}, external_id: {self.external_id}, name: {self.name}, crs: {self.crs}, metadata: {self.metadata}>"
+        return f"Seismic<id: {self.id}, external_id: {repr(self.external_id)}, name: {repr(self.name)}, crs: {repr(self.crs)}, metadata: {self.metadata}>"
 
     @staticmethod
     def from_proto(proto) -> "Seismic":
@@ -1123,7 +1139,7 @@ class Partition:
         self.seismic_ids = seismic_ids
 
     def __repr__(self):
-        return f"Partition<id: {self.id}, external_id: {self.external_id}, name: {self.name}>"
+        return f"Partition<id: {self.id}, external_id: {repr(self.external_id)}, name: {repr(self.name)}>"
 
     @staticmethod
     def from_proto(proto) -> "Partition":
@@ -1311,6 +1327,7 @@ class Survey:
         self.custom_coverage = custom_coverage
         self.survey_coverage_source = survey_coverage_source
 
+    # Note that this method converts from a SearchSurveyResult, not a Survey message.
     @staticmethod
     def from_proto(proto) -> "Survey":
         survey = Survey.from_proto_survey(proto.survey)
